@@ -6,6 +6,7 @@ import redis
 from redis.exceptions import ResponseError
 
 from fakeredis import _msgs as msgs
+from fakeredis._helpers import current_time
 from test.testtools import raw_command
 
 
@@ -127,18 +128,27 @@ def test_sort_ro(r: redis.Redis):
     assert r.sort_ro("b", desc=True) == [b"3", b"2", b"1"]
 
 
+@pytest.mark.unsupported_server_types("dragonfly")
 @pytest.mark.min_server("7")
 def test_expiretime(r: redis.Redis):
     r.set("a", "foo")
-    r.expireat("a", 33177117420)
-    assert r.expiretime("a") == 33177117420
+    r.expireat("a", 33_177_117_420)
+    assert r.expiretime("a") == 33_177_117_420
 
 
+@pytest.mark.min_server("7")
+def test_expiretime_dragonfly(r: redis.Redis):
+    r.set("a", "foo")
+    r.expire("a", 5)
+    assert pytest.approx(int(r.expiretime("a"))) == current_time() // 1000 + 5
+
+
+@pytest.mark.unsupported_server_types("dragonfly")
 @pytest.mark.min_server("7")
 def test_pexpiretime(r: redis.Redis):
     r.set("a", "foo")
-    r.pexpireat("a", 33177117420000)
-    assert r.pexpiretime("a") == 33177117420000
+    r.pexpireat("a", 33_177_117_420_000)
+    assert r.pexpiretime("a") == 33_177_117_420_000
 
 
 def test_sort_empty(r: redis.Redis):
